<?php

namespace Litecms\Videogallery\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Videogallery\Http\Requests\VideoGalleryRequest;
use Litecms\Videogallery\Interfaces\VideoGalleryRepositoryInterface;
use Litecms\Videogallery\Models\VideoGallery;

/**
 * Resource controller class for video_gallery.
 */
class VideoGalleryResourceController extends BaseController
{

    /**
     * Initialize video_gallery resource controller.
     *
     * @param type VideoGalleryRepositoryInterface $video_gallery
     *
     * @return null
     */
    public function __construct(VideoGalleryRepositoryInterface $video_gallery)
    {
        parent::__construct();
        $this->repository = $video_gallery;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Videogallery\Repositories\Criteria\VideoGalleryResourceCriteria::class);
    }

    /**
     * Display a list of video_gallery.
     *
     * @return Response
     */
    public function index(VideoGalleryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Videogallery\Repositories\Presenter\VideoGalleryPresenter::class)
                ->$function();
        }

        $video_galleries = $this->repository->paginate();

        return $this->response->title(trans('videogallery::video_gallery.names'))
            ->view('videogallery::video_gallery.index', true)
            ->data(compact('video_galleries'))
            ->output();
    }

    /**
     * Display video_gallery.
     *
     * @param Request $request
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function show(VideoGalleryRequest $request, VideoGallery $video_gallery)
    {

        if ($video_gallery->exists) {
            $view = 'videogallery::video_gallery.show';
        } else {
            $view = 'videogallery::video_gallery.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('videogallery::video_gallery.name'))
            ->data(compact('video_gallery'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new video_gallery.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VideoGalleryRequest $request)
    {

        $video_gallery = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('videogallery::video_gallery.name')) 
            ->view('videogallery::video_gallery.create', true) 
            ->data(compact('video_gallery'))
            ->output();
    }

    /**
     * Create new video_gallery.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VideoGalleryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $video_gallery                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('videogallery::video_gallery.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('videogallery/video_gallery/' . $video_gallery->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/videogallery/video_gallery'))
                ->redirect();
        }

    }

    /**
     * Show video_gallery for editing.
     *
     * @param Request $request
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function edit(VideoGalleryRequest $request, VideoGallery $video_gallery)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('videogallery::video_gallery.name'))
            ->view('videogallery::video_gallery.edit', true)
            ->data(compact('video_gallery'))
            ->output();
    }

    /**
     * Update the video_gallery.
     *
     * @param Request $request
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function update(VideoGalleryRequest $request, VideoGallery $video_gallery)
    {
        try {
            $attributes = $request->all();

            $video_gallery->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('videogallery::video_gallery.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('videogallery/video_gallery/' . $video_gallery->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('videogallery/video_gallery/' . $video_gallery->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the video_gallery.
     *
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function destroy(VideoGalleryRequest $request, VideoGallery $video_gallery)
    {
        try {

            $video_gallery->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('videogallery::video_gallery.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('videogallery/video_gallery/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('videogallery/video_gallery/' . $video_gallery->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple video_gallery.
     *
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function delete(VideoGalleryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('videogallery::video_gallery.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('videogallery/video_gallery'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/videogallery/video_gallery'))
                ->redirect();
        }

    }

    /**
     * Restore deleted video_galleries.
     *
     * @param Model   $video_gallery
     *
     * @return Response
     */
    public function restore(VideoGalleryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('videogallery::video_gallery.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/videogallery/video_gallery'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/videogallery/video_gallery/'))
                ->redirect();
        }

    }

}
